#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
Author: Yc-Ma
Desc: Main entry point for the mcp-wx-chatinsight application
Time: 2024-03-21 00:00:00
"""

def main():
    print("Hello from mcp-wx-chatinsight!")


if __name__ == "__main__":
    main()
