-- 示例数据库模式

-- test1.wx_record definition

CREATE TABLE `wx_record` (
  `RECORD_ID` bigint NOT NULL AUTO_INCREMENT,
  `UID` varchar(500) DEFAULT NULL,
  `ACCT_ID` int DEFAULT NULL,
  `WX_ACCT` varchar(200) DEFAULT NULL COMMENT '微信号',
  `FROM_WXH` varchar(200) DEFAULT NULL COMMENT '发言人',
  `FROM_WX_ID` varchar(200) DEFAULT NULL COMMENT '发言人ID',
  `RECEIVE_WX_ID` varchar(200) DEFAULT NULL COMMENT '消息接收者ID',
  `WX_GROUP` varchar(200) DEFAULT NULL COMMENT '群号',
  `WX_GROUP_ID` varchar(255) DEFAULT NULL COMMENT '群ID',
  `MSG_TIME` varchar(100) DEFAULT NULL COMMENT '消息时间，格式：YYYY-MM-DD HH:MM:SS',
  `CONTENT_TYPE` int DEFAULT NULL COMMENT '消息类型 文本（0）、语音（4）、文件（6）、图片（8）、视频（10）、链接（12）、自定义表情（18）、未知类型（空）、引用 31、小程序 33、 地址 30 、名片 24、未解析，原始字段 404',
  `CONTENT` text,
  `CONTENT2` varchar(4000) DEFAULT NULL COMMENT '语音转文字',
  `TAGS` varchar(2000) DEFAULT NULL COMMENT '打标',
  `TAG_TYPE` varchar(1000) DEFAULT NULL COMMENT '标签类型',
  `IS_NOTIFY` int DEFAULT NULL COMMENT '是否通知',
  `REF_FILE` varchar(255) DEFAULT NULL COMMENT '文件名字',
  `REF_FILE_ID` varchar(255) DEFAULT NULL COMMENT '文件ID',
  `REMARK` varchar(1000) DEFAULT NULL,
  `CREATE_DT` datetime DEFAULT NULL,
  `VERSION` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `STATE` varchar(10) DEFAULT NULL,
  `CHECK_STATE` varchar(20) DEFAULT NULL,
  `FLAG1` varchar(20) DEFAULT NULL,
  `FLAG2` varchar(20) DEFAULT NULL,
  `MSG_ID` varchar(100) DEFAULT NULL,
  `STATUS` int unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (`RECORD_ID`) USING BTREE,
  KEY `IDX_WXH` (`WX_ACCT`) USING BTREE,
  KEY `IDX_ID` (`ACCT_ID`) USING BTREE,
  KEY `IDX_UID` (`UID`) USING BTREE,
  KEY `wx_record_FROM_WXH_IDX` (`FROM_WXH`,`FROM_WX_ID`) USING BTREE,
  KEY `wx_record_WX_GROUP_IDX` (`WX_GROUP`,`WX_GROUP_ID`) USING BTREE,
  KEY `MSG_ID` (`MSG_ID`),
  KEY `STATUS` (`STATUS`),
  KEY `RECEIVE_WX_ID` (`RECEIVE_WX_ID`),
  KEY `MSG_TIME` (`MSG_TIME`)
) ENGINE=InnoDB AUTO_INCREMENT=678774 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;

-- test2.wx_record definition

CREATE TABLE `wx_record` (
  `RECORD_ID` bigint NOT NULL AUTO_INCREMENT,
  `UID` varchar(500) DEFAULT NULL,
  `ACCT_ID` int DEFAULT NULL,
  `WX_ACCT` varchar(200) DEFAULT NULL COMMENT '微信号',
  `FROM_WXH` varchar(200) DEFAULT NULL COMMENT '发言人',
  `FROM_WX_ID` varchar(200) DEFAULT NULL COMMENT '发言人ID',
  `RECEIVE_WX_ID` varchar(200) DEFAULT NULL COMMENT '消息接收者ID',
  `WX_GROUP` varchar(200) DEFAULT NULL COMMENT '群号',
  `WX_GROUP_ID` varchar(255) DEFAULT NULL COMMENT '群ID',
  `MSG_TIME` varchar(100) DEFAULT NULL COMMENT '消息时间，格式：YYYY-MM-DD HH:MM:SS',
  `CONTENT_TYPE` int DEFAULT NULL COMMENT '消息类型 文本（0）、语音（4）、文件（6）、图片（8）、视频（10）、链接（12）、自定义表情（18）、未知类型（空）、引用 31、小程序 33、 地址 30 、名片 24、未解析，原始字段 404',
  `CONTENT` text,
  `CONTENT2` varchar(4000) DEFAULT NULL COMMENT '语音转文字',
  `TAGS` varchar(2000) DEFAULT NULL COMMENT '打标',
  `TAG_TYPE` varchar(1000) DEFAULT NULL COMMENT '标签类型',
  `IS_NOTIFY` int DEFAULT NULL COMMENT '是否通知',
  `REF_FILE` varchar(255) DEFAULT NULL COMMENT '文件名字',
  `REF_FILE_ID` varchar(255) DEFAULT NULL COMMENT '文件ID',
  `REMARK` varchar(1000) DEFAULT NULL,
  `CREATE_DT` datetime DEFAULT NULL,
  `VERSION` timestamp NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
  `STATE` varchar(10) DEFAULT NULL,
  `CHECK_STATE` varchar(20) DEFAULT NULL,
  `FLAG1` varchar(20) DEFAULT NULL,
  `FLAG2` varchar(20) DEFAULT NULL,
  `MSG_ID` varchar(100) DEFAULT NULL,
  `STATUS` int unsigned NOT NULL DEFAULT '1',
  PRIMARY KEY (`RECORD_ID`) USING BTREE,
  KEY `IDX_WXH` (`WX_ACCT`) USING BTREE,
  KEY `IDX_ID` (`ACCT_ID`) USING BTREE,
  KEY `IDX_UID` (`UID`) USING BTREE,
  KEY `wx_record_FROM_WXH_IDX` (`FROM_WXH`,`FROM_WX_ID`) USING BTREE,
  KEY `wx_record_WX_GROUP_IDX` (`WX_GROUP`,`WX_GROUP_ID`) USING BTREE,
  KEY `MSG_ID` (`MSG_ID`),
  KEY `STATUS` (`STATUS`),
  KEY `RECEIVE_WX_ID` (`RECEIVE_WX_ID`),
  KEY `MSG_TIME` (`MSG_TIME`)
) ENGINE=InnoDB AUTO_INCREMENT=678774 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_0900_ai_ci;
